==> v1.9.0.0.zip: wbm/WBM/features/oldGunSound.cs <==
using BepInEx.Configuration;

using System;
using System.Reflection;

using CAudioClip = DMJGLPCLOPG;

namespace WBM
{
    public partial class WBM
    {
        private ConfigEntry<bool> useOldGunSoundConf;

        private FieldInfo oldGunSoundRef;
        private CAudioClip oldGunSoundRaw
        {
            get
            {
                return (CAudioClip)this.oldGunSoundRef.GetValue(this.webguy);
            }
        }
        private CAudioClip oldGunSound;

        private FieldInfo AKSoundRef;
        private CAudioClip AKSoundRaw
        {
            get
            {
                return (CAudioClip)this.AKSoundRef.GetValue(this.webguy);
            }
            set
            {
                this.AKSoundRef.SetValue(this.webguy, value);
            }
        }
        private CAudioClip newAKSound;

        private FieldInfo SMGSoundRef;
        private CAudioClip SMGSoundRaw
        {
            get
            {
                return (CAudioClip)this.SMGSoundRef.GetValue(this.webguy);
            }
            set
            {
                this.SMGSoundRef.SetValue(this.webguy, value);
            }
        }
        private CAudioClip newSMGSound;

        private void setupOldGunSound()
        {
            this.oldGunSoundRef = webguyType.GetField(MangledNames.gunShotClip, bindFlags);
            this.AKSoundRef = webguyType.GetField(MangledNames.AKRifleShotClip, bindFlags);
            this.SMGSoundRef = webguyType.GetField(MangledNames.SMGShotClip, bindFlags);

            this.useOldGunSoundConf = Config.Bind("Config", "use old gun sound", true);
            this.useOldGunSoundConf.SettingChanged += this.onOldGunSoundChange;
            this.onOldGunSoundChange(new object(), new EventArgs());

            this.oldGunSound = this.oldGunSoundRaw;
            this.newAKSound = this.AKSoundRaw;
            this.newSMGSound = this.SMGSoundRaw;
        }

        private void onOldGunSoundChange(object sender, EventArgs e)
        {
            if (this.useOldGunSoundConf.Value)
            {
                this.AKSoundRaw = this.oldGunSound;
                this.SMGSoundRaw = this.oldGunSound;
            }
            else
            {
                this.AKSoundRaw = this.newAKSound;
                this.SMGSoundRaw = this.newSMGSound;
            }
        }
    }
}

==> v1.14.0.0.zip: wbm/WBM/features/oldGunSound.cs <==
using BepInEx.Configuration;

using System;
using System.Reflection;

using CAudioClip = KGEACBNNOIM;

namespace WBM
{
    public partial class WBM
    {
        private ConfigEntry<bool> useOldGunSoundConf;

        private CAudioClip oldGunSound;

        private FieldInfo AKSoundRef;
        private CAudioClip AKSoundRaw
        {
            set
            {
                this.AKSoundRef.SetValue(this.webguy, value);
            }
        }
        private CAudioClip newAKSound;

        private FieldInfo SMGSoundRef;
        private CAudioClip SMGSoundRaw
        {
            set
            {
                this.SMGSoundRef.SetValue(this.webguy, value);
            }
        }
        private CAudioClip newSMGSound;

        private void setupOldGunSound()
        {
            this.useOldGunSoundConf = Config.Bind("Config", "use old gun sound", true);
            this.useOldGunSoundConf.SettingChanged += this.onOldGunSoundChange;

            this.AKSoundRef = webguyType.GetField(MangledNames.AKRifleShotClip, bindFlags);
            this.SMGSoundRef = webguyType.GetField(MangledNames.SMGShotClip, bindFlags);


            this.oldGunSound = new CAudioClip("Sound/gun_shot", 1f, 0f);
            this.oldGunSound.DMMKODLJJGP(50f, 1_000f);

            this.newAKSound = new CAudioClip("Sound/AK47_Krinkov_Close_Single", 1f, 0f);
            this.newAKSound.DMMKODLJJGP(50f, 1_000f);

            this.newSMGSound = new CAudioClip("Sound/smg_gun_shot", 1f, 0f);
            this.newSMGSound.DMMKODLJJGP(50f, 1_000f);

            this.onOldGunSoundChange(new object(), new EventArgs());
        }

        private void onOldGunSoundChange(object sender, EventArgs e)
        {
            if (this.useOldGunSoundConf.Value)
            {
                this.AKSoundRaw = this.oldGunSound;
                this.SMGSoundRaw = this.oldGunSound;
            }
            else
            {
                this.AKSoundRaw = this.newAKSound;
                this.SMGSoundRaw = this.newSMGSound;
            }
        }
    }
}
